pub struct WithPath<T> { /* private fields */ }Implementations
Sourceimpl WithPath<Config>
impl WithPath<Config>
pub fn get_rust_program_list(&self) -> Result<Vec<PathBuf>>
pub fn read_all_programs(&self) -> Result<Vec<Program>>
Sourcepub fn get_programs(&self, name: Option<String>) -> Result<Vec<Program>>
pub fn get_programs(&self, name: Option<String>) -> Result<Vec<Program>>
Read and get all the programs from the workspace.
This method will only return the given program if name exists.
Sourcepub fn get_program(&self, name: &str) -> Result<Program>
pub fn get_program(&self, name: &str) -> Result<Program>
Get the specified program from the workspace.
pub fn canonicalize_workspace(&self) -> Result<(Vec<PathBuf>, Vec<PathBuf>)>