IdlCommand

Enum IdlCommand 

pub enum IdlCommand {
    Init {
        program_id: Option<Pubkey>,
        filepath: String,
        priority_fee: Option<u64>,
        non_canonical: bool,
    },
    Upgrade {
        program_id: Option<Pubkey>,
        filepath: String,
        priority_fee: Option<u64>,
    },
    Build {
        program_name: Option<String>,
        out: Option<String>,
        out_ts: Option<String>,
        no_docs: bool,
        skip_lint: bool,
        cargo_args: Vec<String>,
    },
    Fetch {
        program_id: Pubkey,
        out: Option<String>,
        non_canonical: bool,
    },
    Convert {
        path: String,
        out: Option<String>,
        program_id: Option<Pubkey>,
    },
    Type {
        path: String,
        out: Option<String>,
    },
    Close {
        program_id: Pubkey,
        seed: String,
        priority_fee: Option<u64>,
    },
    CreateBuffer {
        filepath: String,
        priority_fee: Option<u64>,
    },
    SetBufferAuthority {
        buffer: Pubkey,
        new_authority: Pubkey,
        priority_fee: Option<u64>,
    },
    WriteBuffer {
        program_id: Pubkey,
        buffer: Pubkey,
        seed: String,
        close_buffer: bool,
        priority_fee: Option<u64>,
    },
}

Variants



Init

Initializes a program’s IDL account. Can only be run once.

Fields

program_id: Option<Pubkey>

Program id to initialize IDL for. If not provided, discovers program ID from IDL.

filepath: String
priority_fee: Option<u64>
non_canonical: bool

Create non-canonical metadata account (third-party metadata)



Upgrade

Upgrades the IDL to the new file. An alias for first writing and then then setting the idl buffer account.

Fields

program_id: Option<Pubkey>

Program id to upgrade IDL for. If not provided, discovers program ID from IDL.

filepath: String
priority_fee: Option<u64>


Build

Generates the IDL for the program using the compilation method.

Fields

program_name: Option<String>
out: Option<String>

Output file for the IDL (stdout if not specified)

out_ts: Option<String>

Output file for the TypeScript IDL

no_docs: bool

Suppress doc strings in output

skip_lint: bool

Do not check for safety comments

cargo_args: Vec<String>

Arguments to pass to the underlying cargo test command



Fetch

Fetches an IDL for the given program from a cluster.

Fields

program_id: Pubkey
out: Option<String>

Output file for the IDL (stdout if not specified).

non_canonical: bool

Fetch non-canonical metadata account (third-party metadata)



Convert

Convert legacy IDLs (pre Anchor 0.30) to the new IDL spec

Fields

path: String

Path to the IDL file

out: Option<String>

Output file for the IDL (stdout if not specified)

program_id: Option<Pubkey>

Program id to initialize IDL for. If not provided, discovers program ID from IDL.



Type

Generate TypeScript type for the IDL

Fields

path: String

Path to the IDL file

out: Option<String>

Output file for the IDL (stdout if not specified)



Close

Close a metadata account and recover rent

Fields

program_id: Pubkey

The program ID

seed: String

The seed used for the metadata account (default: “idl”)

priority_fee: Option<u64>

Priority fees in micro-lamports per compute unit



CreateBuffer

Create a buffer account for metadata

Fields

filepath: String

Path to the metadata file

priority_fee: Option<u64>

Priority fees in micro-lamports per compute unit



SetBufferAuthority

Set a new authority on a buffer account

Fields

buffer: Pubkey

The buffer account address

new_authority: Pubkey

The new authority

priority_fee: Option<u64>

Priority fees in micro-lamports per compute unit



WriteBuffer

Write metadata using a buffer account

Fields

program_id: Pubkey

The program ID

buffer: Pubkey

The buffer account address

seed: String

The seed to use for the metadata account (default: “idl”)

close_buffer: bool

Close the buffer after writing

priority_fee: Option<u64>

Priority fees in micro-lamports per compute unit