ProgramCommand

Enum ProgramCommand 

pub enum ProgramCommand {
    Deploy {
        program_filepath: Option<String>,
        program_name: Option<String>,
        program_keypair: Option<String>,
        upgrade_authority: Option<String>,
        program_id: Option<Pubkey>,
        buffer: Option<Pubkey>,
        max_len: Option<usize>,
        no_idl: bool,
        make_final: bool,
        solana_args: Vec<String>,
    },
    WriteBuffer {
        program_filepath: Option<String>,
        program_name: Option<String>,
        buffer: Option<String>,
        buffer_authority: Option<String>,
        max_len: Option<usize>,
    },
    SetBufferAuthority {
        buffer: Pubkey,
        new_buffer_authority: Pubkey,
    },
    SetUpgradeAuthority {
        program_id: Pubkey,
        new_upgrade_authority: Option<Pubkey>,
        new_upgrade_authority_signer: Option<String>,
        skip_new_upgrade_authority_signer_check: bool,
        make_final: bool,
        upgrade_authority: Option<String>,
    },
    Show {
        account: Pubkey,
        get_programs: bool,
        get_buffers: bool,
        all: bool,
    },
    Upgrade {
        program_id: Pubkey,
        program_filepath: Option<String>,
        program_name: Option<String>,
        buffer: Option<Pubkey>,
        upgrade_authority: Option<String>,
        max_retries: u32,
        solana_args: Vec<String>,
    },
    Dump {
        account: Pubkey,
        output_file: String,
    },
    Close {
        account: Option<Pubkey>,
        program_name: Option<String>,
        authority: Option<String>,
        recipient: Option<Pubkey>,
        bypass_warning: bool,
    },
    Extend {
        program_id: Option<Pubkey>,
        program_name: Option<String>,
        additional_bytes: usize,
    },
}

Variants



Deploy

Deploy an upgradeable program

Fields

program_filepath: Option<String>

Program filepath (e.g., target/deploy/my_program.so). If not provided, discovers programs from workspace

program_name: Option<String>

Program name to deploy (from workspace). Used when program_filepath is not provided

program_keypair: Option<String>

Program keypair filepath (defaults to target/deploy/{program_name}-keypair.json)

upgrade_authority: Option<String>

Upgrade authority keypair (defaults to configured wallet)

program_id: Option<Pubkey>

Program id to deploy to (derived from program-keypair if not specified)

buffer: Option<Pubkey>

Buffer account to use for deployment

max_len: Option<usize>

Maximum transaction length (BPF loader upgradeable limit)

no_idl: bool

Don’t upload IDL during deployment (IDL is uploaded by default)

make_final: bool

Make the program immutable after deployment (cannot be upgraded)

solana_args: Vec<String>

Additional arguments to configure deployment (e.g., –with-compute-unit-price 1000)



WriteBuffer

Write a program into a buffer account

Fields

program_filepath: Option<String>

Program filepath (e.g., target/deploy/my_program.so). If not provided, discovers program from workspace using program_name

program_name: Option<String>

Program name to write (from workspace). Used when program_filepath is not provided

buffer: Option<String>

Buffer account keypair (defaults to new keypair)

buffer_authority: Option<String>

Buffer authority (defaults to configured wallet)

max_len: Option<usize>

Maximum transaction length



SetBufferAuthority

Set a new buffer authority

Fields

buffer: Pubkey

Buffer account address

new_buffer_authority: Pubkey

New buffer authority



SetUpgradeAuthority

Set a new program authority

Fields

program_id: Pubkey

Program id

new_upgrade_authority: Option<Pubkey>

New upgrade authority pubkey

new_upgrade_authority_signer: Option<String>

New upgrade authority signer (keypair file). Required unless –skip-new-upgrade-authority-signer-check is used. When provided, both current and new authority will sign (checked mode, recommended)

skip_new_upgrade_authority_signer_check: bool

Skip new upgrade authority signer check. Allows setting authority with only current authority signature. WARNING: Less safe - use only if you’re confident the pubkey is correct

make_final: bool

Make the program immutable (cannot be upgraded)

upgrade_authority: Option<String>

Current upgrade authority keypair (defaults to configured wallet)



Show

Display information about a buffer or program

Fields

account: Pubkey

Account address (buffer or program)

get_programs: bool

Get account information from the Solana config file

get_buffers: bool

Get account information from the Solana config file

all: bool

Show all accounts



Upgrade

Upgrade an upgradeable program

Fields

program_id: Pubkey

Program id to upgrade

program_filepath: Option<String>

Program filepath (e.g., target/deploy/my_program.so). If not provided, discovers from workspace

program_name: Option<String>

Program name to upgrade (from workspace). Used when program_filepath is not provided

buffer: Option<Pubkey>

Existing buffer account to upgrade from. If not provided, auto-discovers program from workspace

upgrade_authority: Option<String>

Upgrade authority (defaults to configured wallet)

max_retries: u32

Max times to retry on failure

solana_args: Vec<String>

Additional arguments to configure deployment (e.g., –with-compute-unit-price 1000)



Dump

Write the program data to a file

Fields

account: Pubkey

Program account address

output_file: String

Output file path



Close

Close a program or buffer account and withdraw all lamports

Fields

account: Option<Pubkey>

Account address to close (buffer or program). If not provided, discovers program from workspace using program_name

program_name: Option<String>

Program name to close (from workspace). Used when account is not provided

authority: Option<String>

Authority keypair (defaults to configured wallet)

recipient: Option<Pubkey>

Recipient address for reclaimed lamports (defaults to authority)

bypass_warning: bool

Bypass warning prompts



Extend

Extend the length of an upgradeable program

Fields

program_id: Option<Pubkey>

Program id to extend. If not provided, discovers program from workspace using program_name

program_name: Option<String>

Program name to extend (from workspace). Used when program_id is not provided

additional_bytes: usize

Additional bytes to allocate