pub fn prepend_compute_unit_ix(
instructions: Vec<Instruction>,
client: &RpcClient,
priority_fee: Option<u64>,
) -> Result<Vec<Instruction>>Expand description
Prepend a compute unit ix, if the priority fee is greater than 0.
pub fn prepend_compute_unit_ix(
instructions: Vec<Instruction>,
client: &RpcClient,
priority_fee: Option<u64>,
) -> Result<Vec<Instruction>>Prepend a compute unit ix, if the priority fee is greater than 0.