pub fn create_program(
name: &str,
template: ProgramTemplate,
test_template: Option<&TestTemplate>,
) -> Result<()>Expand description
Create a program from the given name and template.
pub fn create_program(
name: &str,
template: ProgramTemplate,
test_template: Option<&TestTemplate>,
) -> Result<()>Create a program from the given name and template.