Module template

Module template 

Enums

AnchorVersion
Anchor template version to generate.
ProgramTemplate
Program initialization template
TestTemplate
Test initialization template

Functions

create_program
Create a program from the given name and template.
deploy_js_script_host
deploy_script
deploy_ts_script_host
get_or_create_program_id
Read the program keypair file or create a new one if it doesn’t exist.
git_ignore
js_jest
mocha
node_shell
package_json
prettier_ignore
tests_cargo_toml
ts_config
ts_deploy_script
ts_jest
ts_mocha
ts_package_json