Command

Enum Command 

pub enum Command {
Show 28 variants Init { name: String, javascript: bool, no_install: bool, package_manager: PackageManager, no_git: bool, template: ProgramTemplate, test_template: TestTemplate, force: bool, install_agent_skills: bool, }, Build {
Show 13 fields skip_lint: bool, ignore_keys: bool, no_idl: bool, idl: Option<String>, idl_ts: Option<String>, verifiable: bool, program_name: Option<String>, solana_version: Option<String>, docker_image: Option<String>, bootstrap: BootstrapMode, env: Vec<String>, cargo_args: Vec<String>, no_docs: bool,
}, Expand { program_name: Option<String>, cargo_args: Vec<String>, }, Verify { program_id: Pubkey, repo_url: Option<String>, commit_hash: Option<String>, current_dir: bool, program_name: Option<String>, args: Vec<String>, }, Test { program_name: Option<String>, skip_deploy: bool, skip_lint: bool, skip_local_validator: bool, skip_build: bool, no_idl: bool, detach: bool, run: Vec<String>, validator: ValidatorType, args: Vec<String>, env: Vec<String>, cargo_args: Vec<String>, }, New { name: String, template: ProgramTemplate, force: bool, }, Idl { subcmd: IdlCommand, }, Clean, Deploy { program_name: Option<String>, program_keypair: Option<String>, verifiable: bool, no_idl: bool, solana_args: Vec<String>, }, Migrate, Upgrade { program_id: Pubkey, program_filepath: String, max_retries: u32, solana_args: Vec<String>, }, Airdrop { amount: f64, pubkey: Option<Pubkey>, }, Cluster { subcmd: ClusterCommand, }, Config { subcmd: ConfigCommand, }, Shell, Run { script: String, script_args: Vec<String>, }, Keys { subcmd: KeysCommand, }, Localnet { skip_build: bool, skip_deploy: bool, skip_lint: bool, ignore_keys: bool, validator: ValidatorType, env: Vec<String>, cargo_args: Vec<String>, }, Account { account_type: String, address: Pubkey, idl: Option<String>, }, Completions { shell: Shell, }, Address, Balance { pubkey: Option<Pubkey>, lamports: bool, }, Epoch, EpochInfo, Logs { include_votes: bool, address: Option<Vec<Pubkey>>, }, ShowAccount { cmd: ShowAccountCommand, }, Keygen { subcmd: KeygenCommand, }, Program { subcmd: ProgramCommand, },
}

Variants



Init

Initializes a workspace.

Fields

name: String

Workspace name

javascript: bool

Use JavaScript instead of TypeScript

no_install: bool

Don’t install JavaScript dependencies

package_manager: PackageManager

Package Manager to use

no_git: bool

Don’t initialize git

template: ProgramTemplate

Rust program template to use

test_template: TestTemplate

Test template to use

force: bool

Initialize even if there are files

install_agent_skills: bool

Install Solana agent skills



Build

Builds the workspace.

Fields

skip_lint: bool

True if the build should not fail even if there are no “CHECK” comments

ignore_keys: bool

Skip checking for program ID mismatch between keypair and declare_id

no_idl: bool

Do not build the IDL

idl: Option<String>

Output directory for the IDL.

idl_ts: Option<String>

Output directory for the TypeScript IDL.

verifiable: bool

True if the build artifact needs to be deterministic and verifiable.

program_name: Option<String>

Name of the program to build

solana_version: Option<String>

Version of the Solana toolchain to use. For –verifiable builds only.

docker_image: Option<String>

Docker image to use. For –verifiable builds only.

bootstrap: BootstrapMode

Bootstrap docker image from scratch, installing all requirements for verifiable builds. Only works for debian-based images.

env: Vec<String>

Environment variables to pass into the docker container

cargo_args: Vec<String>

Arguments to pass to the underlying cargo build-sbf command

no_docs: bool

Suppress doc strings in IDL output



Expand

Expands macros (wrapper around cargo expand)

Use it in a program folder to expand program

Use it in a workspace but outside a program folder to expand the entire workspace

Fields

program_name: Option<String>

Expand only this program

cargo_args: Vec<String>

Arguments to pass to the underlying cargo expand command



Verify

Verifies the on-chain bytecode matches the locally compiled artifact. Run this command inside a program subdirectory, i.e., in the dir containing the program’s Cargo.toml.

Fields

program_id: Pubkey

The program ID to verify.

repo_url: Option<String>

The URL of the repository to verify against. Conflicts with --current-dir.

commit_hash: Option<String>

The commit hash to verify against. Requires --repo-url.

current_dir: bool

Verify against the source code in the current directory. Conflicts with --repo-url.

program_name: Option<String>

Name of the program to run the command on. Defaults to the package name.

args: Vec<String>

Any additional arguments to pass to solana-verify.



Test

Runs integration tests.

Fields

program_name: Option<String>

Build and test only this program

skip_deploy: bool

Use this flag if you want to run tests against previously deployed programs.

skip_lint: bool

True if the build should not fail even if there are no “CHECK” comments where normally required

skip_local_validator: bool

Flag to skip starting a local validator, if the configured cluster url is a localnet.

skip_build: bool

Flag to skip building the program in the workspace, use this to save time when running test and the program code is not altered.

no_idl: bool

Do not build the IDL

detach: bool

Flag to keep the local validator running after tests to be able to check the transactions.

run: Vec<String>

Run the test suites under the specified path

validator: ValidatorType

Validator type to use for local testing

args: Vec<String>
env: Vec<String>

Environment variables to pass into the docker container

cargo_args: Vec<String>

Arguments to pass to the underlying cargo build-sbf command.



New

Creates a new program.

Fields

name: String

Program name

template: ProgramTemplate

Rust program template to use

force: bool

Create new program even if there is already one



Idl

Commands for interacting with interface definitions.

Fields

subcmd: IdlCommand


Clean

Remove all artifacts from the generated directories except program keypairs.



Deploy

👎Deprecated since 0.32.0:

use anchor program deploy instead

Deploys each program in the workspace.

Fields

program_name: Option<String>
👎Deprecated since 0.32.0:

use anchor program deploy instead

Only deploy this program

program_keypair: Option<String>
👎Deprecated since 0.32.0:

use anchor program deploy instead

Keypair of the program (filepath) (requires program-name)

verifiable: bool
👎Deprecated since 0.32.0:

use anchor program deploy instead

If true, deploy from path target/verifiable

no_idl: bool
👎Deprecated since 0.32.0:

use anchor program deploy instead

Don’t upload IDL during deployment (IDL is uploaded by default)

solana_args: Vec<String>
👎Deprecated since 0.32.0:

use anchor program deploy instead

Arguments to pass to the underlying solana program deploy command.



Migrate

Runs the deploy migration script.



Upgrade

👎Deprecated since 0.32.0:

use anchor program upgrade instead

Deploys, initializes an IDL, and migrates all in one command. Upgrades a single program. The configured wallet must be the upgrade authority.

Fields

program_id: Pubkey
👎Deprecated since 0.32.0:

use anchor program upgrade instead

The program to upgrade.

program_filepath: String
👎Deprecated since 0.32.0:

use anchor program upgrade instead

Filepath to the new program binary.

max_retries: u32
👎Deprecated since 0.32.0:

use anchor program upgrade instead

Max times to retry on failure.

solana_args: Vec<String>
👎Deprecated since 0.32.0:

use anchor program upgrade instead

Arguments to pass to the underlying solana program deploy command.



Airdrop

Request an airdrop of SOL

Fields

amount: f64

Amount of SOL to airdrop

pubkey: Option<Pubkey>

Recipient address (defaults to configured wallet)



Cluster

Cluster commands.

Fields



Config

Configuration management commands.

Fields



Shell

Starts a node shell with an Anchor client setup according to the local config.



Run

Runs the script defined by the current workspace’s Anchor.toml.

Fields

script: String

The name of the script to run.

script_args: Vec<String>

Argument to pass to the underlying script.



Keys

Program keypair commands.

Fields



Localnet

Localnet commands.

Fields

skip_build: bool

Flag to skip building the program in the workspace, use this to save time when running test and the program code is not altered.

skip_deploy: bool

Use this flag if you want to run tests against previously deployed programs.

skip_lint: bool

True if the build should not fail even if there are no “CHECK” comments where normally required

ignore_keys: bool

Skip checking for program ID mismatch between keypair and declare_id

validator: ValidatorType

Validator type to use for local testing

env: Vec<String>

Environment variables to pass into the docker container

cargo_args: Vec<String>

Arguments to pass to the underlying cargo build-sbf command.



Account

Fetch and deserialize an account using the IDL provided.

Fields

account_type: String

Account struct to deserialize (format: <program_name>.)

address: Pubkey

Address of the account to deserialize

idl: Option<String>

IDL to use (defaults to workspace IDL)



Completions

Generates shell completions.

Fields

shell: Shell


Address

Get your public key



Balance

Get your balance

Fields

pubkey: Option<Pubkey>

Account to check balance for (defaults to configured wallet)

lamports: bool

Display balance in lamports instead of SOL



Epoch

Get current epoch



EpochInfo

Get information about the current epoch



Logs

Stream transaction logs

Fields

include_votes: bool

Include vote transactions when monitoring all transactions

address: Option<Vec<Pubkey>>

Addresses to filter logs by



ShowAccount

Show the contents of an account

Fields

cmd: ShowAccountCommand


Keygen

Keypair generation and management

Fields



Program

Program deployment and management commands

Fields